@@ -1,5 +1,4 @@
 /*
- * gedit-commands-file.c
  * This file is part of gedit
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
@@ -21,8 +20,6 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-
 #include "gedit-commands.h"
 #include "gedit-commands-private.h"
 
@@ -30,32 +27,31 @@
 #include <tepl/tepl.h>
 
 #include "gedit-app.h"
+#include "gedit-close-confirmation-dialog.h"
 #include "gedit-debug.h"
 #include "gedit-document.h"
 #include "gedit-document-private.h"
-#include "gedit-tab.h"
-#include "gedit-tab-private.h"
-#include "gedit-window-private.h"
-#include "gedit-notebook.h"
-#include "gedit-statusbar.h"
-#include "gedit-utils.h"
 #include "gedit-file-chooser-dialog.h"
 #include "gedit-file-chooser-open.h"
-#include "gedit-close-confirmation-dialog.h"
+#include "gedit-notebook.h"
+#include "gedit-statusbar.h"
+#include "gedit-tab.h"
+#include "gedit-tab-private.h"
+#include "gedit-utils.h"
+#include "gedit-window-private.h"
 
-/* useful macro */
 #define GBOOLEAN_TO_POINTER(i) (GINT_TO_POINTER ((i) ? 2 : 1))
 #define GPOINTER_TO_BOOLEAN(i) ((gboolean) ((GPOINTER_TO_INT(i) == 2) ? TRUE : FALSE))
 
-#define GEDIT_IS_CLOSING_ALL "gedit-is-closing-all"
-#define GEDIT_NOTEBOOK_TO_CLOSE "gedit-notebook-to-close"
-#define GEDIT_IS_QUITTING "gedit-is-quitting"
-#define GEDIT_IS_QUITTING_ALL "gedit-is-quitting-all"
+#define GEDIT_IS_CLOSING_ALL     "gedit-is-closing-all"
+#define GEDIT_NOTEBOOK_TO_CLOSE  "gedit-notebook-to-close"
+#define GEDIT_IS_QUITTING        "gedit-is-quitting"
+#define GEDIT_IS_QUITTING_ALL    "gedit-is-quitting-all"
 
 void
 _gedit_cmd_file_new (GSimpleAction *action,
-                     GVariant      *parameter,
-                     gpointer       user_data)
+		     GVariant      *parameter,
+		     gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 
@@ -396,8 +392,8 @@ file_chooser_open_done_cb (GeditFileChooserOpen *file_chooser,
 
 void
 _gedit_cmd_file_open (GSimpleAction *action,
-                      GVariant      *parameter,
-                      gpointer       user_data)
+		      GVariant      *parameter,
+		      gpointer       user_data)
 {
 	GeditWindow *window = NULL;
 	GeditFileChooserOpen *file_chooser;
@@ -504,8 +500,8 @@ replace_read_only_file (GtkWindow *parent,
 
 static gboolean
 change_compression (GtkWindow *parent,
-                    GFile     *file,
-                    gboolean   compressed)
+		    GFile     *file,
+		    gboolean   compressed)
 {
 	GtkWidget *dialog;
 	gint ret;
@@ -1019,8 +1015,8 @@ save_tab (GeditTab    *tab,
 
 void
 _gedit_cmd_file_save (GSimpleAction *action,
-                      GVariant      *parameter,
-                      gpointer       user_data)
+		      GVariant      *parameter,
+		      gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
@@ -1044,8 +1040,8 @@ _gedit_cmd_file_save_as_cb (GeditTab     *tab,
 
 void
 _gedit_cmd_file_save_as (GSimpleAction *action,
-                         GVariant      *parameter,
-                         gpointer       user_data)
+			 GVariant      *parameter,
+			 gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
@@ -1327,8 +1323,8 @@ gedit_commands_save_all_documents (GeditWindow *window)
 
 void
 _gedit_cmd_file_save_all (GSimpleAction *action,
-                          GVariant      *parameter,
-                          gpointer       user_data)
+			  GVariant      *parameter,
+			  gpointer       user_data)
 {
 	gedit_commands_save_all_documents (GEDIT_WINDOW (user_data));
 }
@@ -1343,7 +1339,7 @@ _gedit_cmd_file_save_all (GSimpleAction *action,
  */
 void
 gedit_commands_save_document (GeditWindow   *window,
-                              GeditDocument *document)
+			      GeditDocument *document)
 {
 	GeditTab *tab;
 
@@ -1523,8 +1519,8 @@ revert_dialog (GeditWindow   *window,
 
 void
 _gedit_cmd_file_revert (GSimpleAction *action,
-                        GVariant      *parameter,
-                        gpointer       user_data)
+			GVariant      *parameter,
+			gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
@@ -1609,8 +1605,8 @@ save_and_close (GeditTab    *tab,
 
 static void
 save_and_close_documents (GList         *docs,
-                          GeditWindow   *window,
-                          GeditNotebook *notebook)
+			  GeditWindow   *window,
+			  GeditNotebook *notebook)
 {
 	GList *tabs;
 	GList *l;
@@ -1777,8 +1773,8 @@ close_document (GeditWindow   *window,
 
 static void
 close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
-                                            gint                          response_id,
-                                            GeditWindow                  *window)
+					    gint                          response_id,
+					    GeditWindow                  *window)
 {
 	GList *selected_documents;
 	gboolean is_closing_all;
@@ -1945,8 +1941,8 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 
 void
 _gedit_cmd_file_close (GSimpleAction *action,
-                       GVariant      *parameter,
-                       gpointer       user_data)
+		       GVariant      *parameter,
+		       gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *active_tab;
@@ -1966,7 +1962,7 @@ _gedit_cmd_file_close (GSimpleAction *action,
 
 static void
 file_close_dialog (GeditWindow *window,
-                   GList       *unsaved_docs)
+		   GList       *unsaved_docs)
 {
 	GtkWidget *dlg;
 
@@ -2028,7 +2024,7 @@ notebook_get_unsaved_documents (GeditNotebook *notebook)
 /* Close a notebook */
 void
 _gedit_cmd_file_close_notebook (GeditWindow   *window,
-                                GeditNotebook *notebook)
+				GeditNotebook *notebook)
 {
 	GList *unsaved_docs;
 
@@ -2056,7 +2052,7 @@ _gedit_cmd_file_close_notebook (GeditWindow   *window,
 /* Close all tabs */
 static void
 file_close_all (GeditWindow *window,
-                gboolean     is_quitting)
+		gboolean     is_quitting)
 {
 	GList *unsaved_docs;
 
@@ -2086,8 +2082,8 @@ file_close_all (GeditWindow *window,
 
 void
 _gedit_cmd_file_close_all (GSimpleAction *action,
-                           GVariant      *parameter,
-                           gpointer       user_data)
+			   GVariant      *parameter,
+			   gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 
@@ -2111,16 +2107,15 @@ _gedit_cmd_file_quit (GSimpleAction *action,
 		      GVariant      *parameter,
 		      gpointer       user_data)
 {
-	GApplication *app;
+	GeditApp *app = GEDIT_APP (user_data);
 	GList *windows;
 	GList *l;
 
-	app = g_application_get_default ();
-	windows = gedit_app_get_main_windows (GEDIT_APP (app));
+	windows = gedit_app_get_main_windows (app);
 
 	if (windows == NULL)
 	{
-		g_application_quit (app);
+		g_application_quit (G_APPLICATION (app));
 		return;
 	}
 
